@@ -1,3 +1,4 @@
+import warnings
 import numpy as np
 from numpy.linalg import LinAlgError
 from scipy.optimize._numdiff import approx_derivative
@@ -156,11 +157,7 @@ class BaseObjective(object):
             negative log-posterior
 
         """
-        vals = self.parameters
-        if pvals is not None:
-            vals = pvals
-
-        return -self.logpost(vals)
+        return -self.logpost(pvals)
 
     def varying_parameters(self):
         """
@@ -598,7 +595,7 @@ class Objective(BaseObjective):
 
         # nans play havoc
         if np.isnan(logl).any():
-            raise RuntimeError("Objective.logl encountered a NaN")
+            raise RuntimeError("Objective.logl encountered a NaN.")
 
         # add on extra 'potential' terms from the model.
         extra_potential = self.model.logp()
@@ -1229,6 +1226,13 @@ class Transform(object):
             et = np.copy(etemp)
         elif self.form == "logY":
             yt, et = EP.EPlog10(y, etemp)
+            if not np.isfinite(yt).all():
+                warnings.warn(
+                    "Some of the transformed data was non-finite."
+                    " Please check your datasets for points with zero or"
+                    " negative values.",
+                    RuntimeWarning,
+                )
         elif self.form == "YX4":
             yt = y * np.power(x, 4)
             et = etemp * np.power(x, 4)
